@@ -36,7 +36,7 @@ public:
     explicit AimMainOptionsWidget(ParameterEditModel* model, QWidget* parent = 0);
     virtual ~AimMainOptionsWidget();
 
-    virtual QString defaultDisplayName() const;
+    virtual QString defaultDisplayName() const override;
 private:
     Ui::AimMainOptionsWidget *m_ui;
 };
